@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.4.1'
+VERSION = '0.4.2'
 
 import os
 import sys
@@ -83,7 +83,7 @@ def get_args():
         '-d', '--config-dir',
         dest='config_dir',
         type=str,
-        default='/opt/kernels',
+        default=None,
         help='directory for kernel configs'
     )
 
@@ -185,7 +185,7 @@ class Kernel(object):
             self.config_dir = './configs'
         else:
             self.config_dir = os.path.expanduser(config_dir.rstrip('/'))
-        self.config_dir = os.path.abspat(self.config_dir)
+        self.config_dir = os.path.abspath(self.config_dir)
 
         for subdir in ['/sources', '/archives']:
             os.makedirs(self.build_dir + subdir, 0o755, True)
